pyawair Python Wrapper for getawair.com Air Quality Sensors
=======================



This project is offered under and Apache2 license and is not supported officialy by Awair.

For more information, please visit the project home page at `GITHub.com <https://github
.com/netmanchris/pyawair`_.


What's Changed:

0.0.1  Initial Posting to Pypi. Basic functionality and scaffolding. Lots of work to do.
0.0.2-6 Adding functions, tests,
0.0.7 - First release with class objects - caching provided by @danielsjf
0.0.8 - Refactoring and modification of class objects to optimize API usage